@@ -1,7 +1,7 @@
 /* tls_dummy.c
 ** strophe XMPP client library -- TLS abstraction dummy impl.
 **
-** Copyright (C) 2005-2009 Collecta, Inc. 
+** Copyright (C) 2005-2009 Collecta, Inc.
 **
 **  This software is provided AS-IS with no warranty, either express
 **  or implied.
@@ -35,57 +35,73 @@ void tls_shutdown(void)
 
 tls_t *tls_new(xmpp_conn_t *conn)
 {
+    UNUSED(conn);
     /* always fail */
     return NULL;
 }
 
 void tls_free(tls_t *tls)
 {
+    UNUSED(tls);
     return;
 }
 
 int tls_set_credentials(tls_t *tls, const char *cafilename)
 {
+    UNUSED(tls);
+    UNUSED(cafilename);
     return -1;
 }
 
 int tls_start(tls_t *tls)
 {
+    UNUSED(tls);
     return -1;
 }
 
 int tls_stop(tls_t *tls)
 {
+    UNUSED(tls);
     return -1;
 }
 
 int tls_error(tls_t *tls)
 {
+    UNUSED(tls);
     /* todo: some kind of error polling/dump */
     return 0;
 }
 
 int tls_pending(tls_t *tls)
 {
+    UNUSED(tls);
     return 0;
 }
 
-int tls_read(tls_t *tls, void * const buff, const size_t len)
+int tls_read(tls_t *tls, void *const buff, const size_t len)
 {
+    UNUSED(tls);
+    UNUSED(buff);
+    UNUSED(len);
     return -1;
 }
 
-int tls_write(tls_t *tls, const void * const buff, const size_t len)
+int tls_write(tls_t *tls, const void *const buff, const size_t len)
 {
+    UNUSED(tls);
+    UNUSED(buff);
+    UNUSED(len);
     return -1;
 }
 
 int tls_clear_pending_write(tls_t *tls)
 {
+    UNUSED(tls);
     return -1;
 }
 
 int tls_is_recoverable(int error)
 {
+    UNUSED(error);
     return 0;
 }
