@@ -81,6 +81,7 @@ const char *tls_errors[] = {
     TLS_ERROR_FIELD(SSL_ERROR_ZERO_RETURN),
     TLS_ERROR_FIELD(SSL_ERROR_WANT_CONNECT),
     TLS_ERROR_FIELD(SSL_ERROR_WANT_ACCEPT),
+#ifndef LIBRESSL_VERSION_NUMBER
 #if OPENSSL_VERSION_NUMBER >= 0x10100000L
     TLS_ERROR_FIELD(SSL_ERROR_WANT_ASYNC),
     TLS_ERROR_FIELD(SSL_ERROR_WANT_ASYNC_JOB),
@@ -88,6 +89,7 @@ const char *tls_errors[] = {
 #if OPENSSL_VERSION_NUMBER >= 0x10101000L
     TLS_ERROR_FIELD(SSL_ERROR_WANT_CLIENT_HELLO_CB),
 #endif
+#endif /* !LIBRESSL_VERSION_NUMBER */
 };
 const char *cert_errors[] = {
     TLS_ERROR_FIELD(X509_V_OK),
@@ -148,30 +150,34 @@ const char *cert_errors[] = {
     TLS_ERROR_FIELD(X509_V_ERR_UNSUPPORTED_CONSTRAINT_SYNTAX),
     TLS_ERROR_FIELD(X509_V_ERR_UNSUPPORTED_NAME_SYNTAX),
     TLS_ERROR_FIELD(X509_V_ERR_CRL_PATH_VALIDATION_ERROR),
+#ifndef LIBRESSL_VERSION_NUMBER
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_INVALID_VERSION),
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_INVALID_ALGORITHM),
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_INVALID_CURVE),
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_INVALID_SIGNATURE_ALGORITHM),
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_LOS_NOT_ALLOWED),
     TLS_ERROR_FIELD(X509_V_ERR_SUITE_B_CANNOT_SIGN_P_384_WITH_P_256),
+#endif /* !LIBRESSL_VERSION_NUMBER */
     TLS_ERROR_FIELD(X509_V_ERR_HOSTNAME_MISMATCH),
     TLS_ERROR_FIELD(X509_V_ERR_EMAIL_MISMATCH),
     TLS_ERROR_FIELD(X509_V_ERR_IP_ADDRESS_MISMATCH),
-#endif
+#endif /* OPENSSL_VERSION_NUMBER >= 0x10002000L */
 #if OPENSSL_VERSION_NUMBER >= 0x10100000L
+    TLS_ERROR_FIELD(X509_V_ERR_INVALID_CALL),
+    TLS_ERROR_FIELD(X509_V_ERR_STORE_LOOKUP),
+#ifndef LIBRESSL_VERSION_NUMBER
     TLS_ERROR_FIELD(X509_V_ERR_PATH_LOOP),
     TLS_ERROR_FIELD(X509_V_ERR_DANE_NO_MATCH),
     TLS_ERROR_FIELD(X509_V_ERR_EE_KEY_TOO_SMALL),
     TLS_ERROR_FIELD(X509_V_ERR_CA_KEY_TOO_SMALL),
     TLS_ERROR_FIELD(X509_V_ERR_CA_MD_TOO_WEAK),
-    TLS_ERROR_FIELD(X509_V_ERR_INVALID_CALL),
-    TLS_ERROR_FIELD(X509_V_ERR_STORE_LOOKUP),
     TLS_ERROR_FIELD(X509_V_ERR_NO_VALID_SCTS),
     TLS_ERROR_FIELD(X509_V_ERR_PROXY_SUBJECT_NAME_VIOLATION),
     TLS_ERROR_FIELD(X509_V_ERR_OCSP_VERIFY_NEEDED),
     TLS_ERROR_FIELD(X509_V_ERR_OCSP_VERIFY_FAILED),
     TLS_ERROR_FIELD(X509_V_ERR_OCSP_CERT_UNKNOWN),
-#endif
+#endif /* !LIBRESSL_VERSION_NUMBER */
+#endif /* OPENSSL_VERSION_NUMBER >= 0x10100000L */
 };
 #undef TLS_ERROR_FIELD
 
